@@ -1,3 +1,31 @@
+//Overriding glossary click
+
+var glossary_popup_on = false;
+
+function goto_glossary_definition(num)
+{
+    if (glossary_popup_on)
+    {
+        var node = $(this);
+        popup_node = $("#glossary-definition-popup");
+        if (popup_node.length > 0) {
+            popup_node.hide();
+        }
+        glossary_popup_on = false;
+    }
+    else
+    {
+        var node = $(this);
+        popup_node = $("#glossary-definition-popup");
+        if (popup_node.length > 0) {
+            popup_node.show();
+        }
+        glossary_popup_on = true;
+    }
+    
+    return false;
+}
+
 PorseleinApp = {};
 
 //Set a cookie
