@@ -1,4 +1,13 @@
 
+//Activities Hack
+$(function()
+{
+    if ($(".portlet.portletCollection").find(".portletItem") == 0)
+    {
+        $(".portlet.portletCollection").hide();
+    }
+});
+
 //Slideshow hack to go back from the info button
 slideshowHack = {};
 slideshowHack.referrer = document.referrer
@@ -190,6 +199,15 @@ mediaShow.fullscreen= function (slideshowIndex)
             mediaShow.reAlign()
        }
        $(slideshow.obj).focus();
+       if ($(slideshow.obj)[0].mozRequestFullScreen) {
+            // This is how to go into fullscren mode in Firefox
+            // Note the "moz" prefix, which is short for Mozilla.
+            $(slideshow.obj)[0].mozRequestFullScreen();
+        } else if ($(slideshow.obj)[0].webkitRequestFullScreen) {
+            // This is how to go into fullscreen mode in Chrome and Safari
+            // Both of those browsers are based on the Webkit project, hence the same prefix.
+            $(slideshow.obj)[0].webkitRequestFullScreen();
+        }
     }
     else
     {
